==> openshift-model-operator-5.12.3-sources.jar: io/fabric8/openshift/api/model/operator/v1/KubeAPIServerSpecBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class KubeAPIServerSpecBuilder extends io.fabric8.openshift.api.model.operator.v1.KubeAPIServerSpecFluentImpl<io.fabric8.openshift.api.model.operator.v1.KubeAPIServerSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.KubeAPIServerSpec,io.fabric8.openshift.api.model.operator.v1.KubeAPIServerSpecBuilder>{
  public KubeAPIServerSpecBuilder() {
    this(false);
  }
  public KubeAPIServerSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new KubeAPIServerSpec(), validationEnabled);
  }
  public KubeAPIServerSpecBuilder(io.fabric8.openshift.api.model.operator.v1.KubeAPIServerSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public KubeAPIServerSpecBuilder(io.fabric8.openshift.api.model.operator.v1.KubeAPIServerSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new KubeAPIServerSpec(), validationEnabled);
  }
  public KubeAPIServerSpecBuilder(io.fabric8.openshift.api.model.operator.v1.KubeAPIServerSpecFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.KubeAPIServerSpec instance) {
    this(fluent, instance, false);
  }
  public KubeAPIServerSpecBuilder(io.fabric8.openshift.api.model.operator.v1.KubeAPIServerSpecFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.KubeAPIServerSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withFailedRevisionLimit(instance.getFailedRevisionLimit()); 
    fluent.withForceRedeploymentReason(instance.getForceRedeploymentReason()); 
    fluent.withLogLevel(instance.getLogLevel()); 
    fluent.withManagementState(instance.getManagementState()); 
    fluent.withObservedConfig(instance.getObservedConfig()); 
    fluent.withOperatorLogLevel(instance.getOperatorLogLevel()); 
    fluent.withSucceededRevisionLimit(instance.getSucceededRevisionLimit()); 
    fluent.withUnsupportedConfigOverrides(instance.getUnsupportedConfigOverrides()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public KubeAPIServerSpecBuilder(io.fabric8.openshift.api.model.operator.v1.KubeAPIServerSpec instance) {
    this(instance,false);
  }
  public KubeAPIServerSpecBuilder(io.fabric8.openshift.api.model.operator.v1.KubeAPIServerSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withFailedRevisionLimit(instance.getFailedRevisionLimit()); 
    this.withForceRedeploymentReason(instance.getForceRedeploymentReason()); 
    this.withLogLevel(instance.getLogLevel()); 
    this.withManagementState(instance.getManagementState()); 
    this.withObservedConfig(instance.getObservedConfig()); 
    this.withOperatorLogLevel(instance.getOperatorLogLevel()); 
    this.withSucceededRevisionLimit(instance.getSucceededRevisionLimit()); 
    this.withUnsupportedConfigOverrides(instance.getUnsupportedConfigOverrides()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.KubeAPIServerSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.KubeAPIServerSpec build() {
    KubeAPIServerSpec buildable = new KubeAPIServerSpec(fluent.getFailedRevisionLimit(),fluent.getForceRedeploymentReason(),fluent.getLogLevel(),fluent.getManagementState(),fluent.getObservedConfig(),fluent.getOperatorLogLevel(),fluent.getSucceededRevisionLimit(),fluent.getUnsupportedConfigOverrides());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    KubeAPIServerSpecBuilder that = (KubeAPIServerSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operator-6.3.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/KubeAPIServerSpecBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class KubeAPIServerSpecBuilder extends KubeAPIServerSpecFluentImpl<KubeAPIServerSpecBuilder> implements VisitableBuilder<KubeAPIServerSpec,KubeAPIServerSpecBuilder>{
  public KubeAPIServerSpecBuilder() {
    this(false);
  }
  public KubeAPIServerSpecBuilder(Boolean validationEnabled) {
    this(new KubeAPIServerSpec(), validationEnabled);
  }
  public KubeAPIServerSpecBuilder(KubeAPIServerSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public KubeAPIServerSpecBuilder(KubeAPIServerSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new KubeAPIServerSpec(), validationEnabled);
  }
  public KubeAPIServerSpecBuilder(KubeAPIServerSpecFluent<?> fluent,KubeAPIServerSpec instance) {
    this(fluent, instance, false);
  }
  public KubeAPIServerSpecBuilder(KubeAPIServerSpecFluent<?> fluent,KubeAPIServerSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withFailedRevisionLimit(instance.getFailedRevisionLimit()); 
    fluent.withForceRedeploymentReason(instance.getForceRedeploymentReason()); 
    fluent.withLogLevel(instance.getLogLevel()); 
    fluent.withManagementState(instance.getManagementState()); 
    fluent.withObservedConfig(instance.getObservedConfig()); 
    fluent.withOperatorLogLevel(instance.getOperatorLogLevel()); 
    fluent.withSucceededRevisionLimit(instance.getSucceededRevisionLimit()); 
    fluent.withUnsupportedConfigOverrides(instance.getUnsupportedConfigOverrides()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public KubeAPIServerSpecBuilder(KubeAPIServerSpec instance) {
    this(instance,false);
  }
  public KubeAPIServerSpecBuilder(KubeAPIServerSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withFailedRevisionLimit(instance.getFailedRevisionLimit()); 
    this.withForceRedeploymentReason(instance.getForceRedeploymentReason()); 
    this.withLogLevel(instance.getLogLevel()); 
    this.withManagementState(instance.getManagementState()); 
    this.withObservedConfig(instance.getObservedConfig()); 
    this.withOperatorLogLevel(instance.getOperatorLogLevel()); 
    this.withSucceededRevisionLimit(instance.getSucceededRevisionLimit()); 
    this.withUnsupportedConfigOverrides(instance.getUnsupportedConfigOverrides()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  KubeAPIServerSpecFluent<?> fluent;
  Boolean validationEnabled;
  public KubeAPIServerSpec build() {
    KubeAPIServerSpec buildable = new KubeAPIServerSpec(fluent.getFailedRevisionLimit(),fluent.getForceRedeploymentReason(),fluent.getLogLevel(),fluent.getManagementState(),fluent.getObservedConfig(),fluent.getOperatorLogLevel(),fluent.getSucceededRevisionLimit(),fluent.getUnsupportedConfigOverrides());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
